@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -44,9 +44,7 @@ JobTrackerSearchWidget::JobTrackerSearchWidget(QWidget *parent)
     connect(mSelectColumn, &QComboBox::currentIndexChanged, this, &JobTrackerSearchWidget::slotColumnChanged);
 }
 
-JobTrackerSearchWidget::~JobTrackerSearchWidget()
-{
-}
+JobTrackerSearchWidget::~JobTrackerSearchWidget() = default;
 
 void JobTrackerSearchWidget::slotColumnChanged(int index)
 {
